==> aws-cdk-lib-2.191.0-sources.jar: software/amazon/awscdk/services/route53/targets/IAliasRecordTargetProps.java <==
package software.amazon.awscdk.services.route53.targets;

/**
 * Properties the alias record target.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.110.0 (build 336b265)", date = "2025-04-22T23:08:19.742Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_route53_targets.IAliasRecordTargetProps")
@software.amazon.jsii.Jsii.Proxy(IAliasRecordTargetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IAliasRecordTargetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Evaluate target health.
     * <p>
     * Default: - no health check configuration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getEvaluateTargetHealth() {
        return null;
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.route53.targets.IAliasRecordTargetProps.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Evaluate target health.
         * <p>
         * Default: - no health check configuration
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.Boolean getEvaluateTargetHealth() {
            return software.amazon.jsii.Kernel.get(this, "evaluateTargetHealth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }
    }

    /**
     * Internal default implementation for {@link IAliasRecordTargetProps}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IAliasRecordTargetProps {

        /**
         * Evaluate target health.
         * <p>
         * Default: - no health check configuration
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.Boolean getEvaluateTargetHealth() {
            return software.amazon.jsii.Kernel.get(this, "evaluateTargetHealth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }
    }
}

==> aws-cdk-lib-2.195.0-sources.jar: software/amazon/awscdk/services/route53/targets/IAliasRecordTargetProps.java <==
package software.amazon.awscdk.services.route53.targets;

/**
 * Properties the alias record target.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.110.0 (build 336b265)", date = "2025-05-07T19:18:55.410Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.aws_route53_targets.IAliasRecordTargetProps")
@software.amazon.jsii.Jsii.Proxy(IAliasRecordTargetProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IAliasRecordTargetProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Evaluate target health.
     * <p>
     * Default: - no health check configuration
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getEvaluateTargetHealth() {
        return null;
    }

    /**
     * Target Hosted zone ID.
     * <p>
     * Default: - hosted zone ID for the EBS endpoint will be retrieved based on the stack's region.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneId() {
        return null;
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.route53.targets.IAliasRecordTargetProps.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * Evaluate target health.
         * <p>
         * Default: - no health check configuration
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.Boolean getEvaluateTargetHealth() {
            return software.amazon.jsii.Kernel.get(this, "evaluateTargetHealth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Target Hosted zone ID.
         * <p>
         * Default: - hosted zone ID for the EBS endpoint will be retrieved based on the stack's region.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneId() {
            return software.amazon.jsii.Kernel.get(this, "hostedZoneId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }

    /**
     * Internal default implementation for {@link IAliasRecordTargetProps}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends IAliasRecordTargetProps {

        /**
         * Evaluate target health.
         * <p>
         * Default: - no health check configuration
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.Boolean getEvaluateTargetHealth() {
            return software.amazon.jsii.Kernel.get(this, "evaluateTargetHealth", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Target Hosted zone ID.
         * <p>
         * Default: - hosted zone ID for the EBS endpoint will be retrieved based on the stack's region.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.Nullable java.lang.String getHostedZoneId() {
            return software.amazon.jsii.Kernel.get(this, "hostedZoneId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }
}
